ErrorCode

Enum ErrorCode 

#[non_exhaustive]
#[repr(i32)]
pub enum ErrorCode { Timeout = -1, StreamError = -2, Corruption = -3, Overflow = -4, NotSupported = -5, TimeError = -6, Underflow = -7, Other = 0, }
An error code from SoapySDR

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Timeout = -1

Returned when read has a timeout.



StreamError = -2

Returned for non-specific stream errors.



Corruption = -3

Returned when read has data corruption. For example, the driver saw a malformed packet.



Overflow = -4

Returned when read has an overflow condition. For example, and internal buffer has filled.



NotSupported = -5

Returned when a requested operation or flag setting is not supported by the underlying implementation.



TimeError = -6

Returned when a the device encountered a stream time which was expired (late) or too early to process.



Underflow = -7

Returned when write caused an underflow condition. For example, a continuous stream was interrupted.



Other = 0

Error without a specific code, see error string