Enum Format Copy item path Source #[non_exhaustive]
pub enum Format {
Show 20 variants CF64,
CF32,
CS32,
CU32,
CS16,
CU16,
CS12,
CU12,
CS8,
CU8,
CS4,
CU4,
F64,
F32,
S32,
U32,
S16,
U16,
S8,
U8,
}Expand description This enum is marked as non-exhaustive Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Complex 64-bit floats (complex double)
Complex 32-bit floats (complex float)
Complex signed 32-bit integers (complex int32)
Complex unsigned 32-bit integers (complex uint32)
Complex signed 16-bit integers (complex int16)
Complex unsigned 16-bit integers (complex uint16)
Complex signed 12-bit integers (3 bytes)
Complex unsigned 12-bit integers (3 bytes)
Complex signed 8-bit integers (complex int8)
Complex unsigned 8-bit integers (complex uint8)
Complex signed 4-bit integers (1 byte)
Complex unsigned 4-bit integers (1 byte)
Real 64-bit floats (double)
Real 32-bit floats (float)
Real signed 32-bit integers (int32)
Real unsigned 32-bit integers (uint32)
Real signed 16-bit integers (int16)
Real unsigned 16-bit integers (uint16)
Real signed 8-bit integers (int8)
Real unsigned 8-bit integers (uint8)
Get the name of the format
Get the size of one sample in this format
Performs copy-assignment from
source.
Read more Formats the value using the given formatter.
Read more Formats the value using the given formatter.
Read more The associated error which can be returned from parsing.
Parses a string
s to return a value of this type.
Read more Tests for self and other values to be equal, and is used by ==.
Tests for !=. The default implementation is almost always sufficient,
and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more 🔬 This is a nightly-only experimental API. (clone_to_uninit)
Performs copy-assignment from
self to
dest.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The resulting type after obtaining ownership.
Creates owned data from borrowed data, usually by cloning.
Read more Uses borrowed data to replace owned data, usually by cloning.
Read more Converts the given value to a
String.
Read more The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.