pub fn enumerate<A: Into<Args>>(args: A) -> Result<Vec<Args>, Error>Expand description
Enumerate a list of available devices on the system.
args: a set of arguments to filter the devices returned.
Example (list all devices)
for dev in soapysdr::enumerate("").unwrap() {
println!("{}", dev);
}This function returns a list of argument lists that can be passed to Device::new() to
open the device.